@@ -40,15 +40,12 @@ struct _PangoCairoFcFontMap
   double dpi;
 
   FT_Library library;
-  PangoRenderer *renderer;
 };
 
 GType pango_cairo_fc_font_map_get_type (void) G_GNUC_CONST;
 
-PangoFcFont *_pango_cairo_fc_font_new (PangoCairoFcFontMap        *cffontmap,
-				       PangoContext               *context,
-				       const PangoFontDescription *desc,
-				       FcPattern	          *pattern);
+PangoFcFont *_pango_cairo_fc_font_new (PangoCairoFcFontMap *cffontmap,
+				       PangoFcFontKey      *key);
 FT_Library   _pango_cairo_fc_font_map_get_library (PangoCairoFcFontMap *fontmap);
 
 G_END_DECLS
